package common

import (
	"encoding/json"
	"errors"
	"fmt"
	"io"
	"net/http"
	"os"
)

type Processor struct {
	BaseUrl    string
	ApiToken   string
	HttpClient http.Client
}

func (p *Processor) UserAgent() string {
	return fmt.Sprintf("tripla-fintraffic-rt/%v", os.Getenv("TRIPLA_VERSION"))
}

func (p *Processor) GetAndParseJson(path string, target any) error {
	req, err := http.NewRequest("GET", fmt.Sprintf("%v%v", p.BaseUrl, path), nil)
	if err != nil {
		return err
	}
	req.Header.Set("Authorization", fmt.Sprintf("Bearer %v", p.ApiToken))
	req.Header.Set("User-Agent", p.UserAgent())

	response, err := p.HttpClient.Do(req)
	if err != nil {
		return err
	}
	defer response.Body.Close()

	if response.StatusCode != http.StatusOK {
		return errors.New(fmt.Sprintf("Unexpected status %v %v", response.StatusCode, response.Status))
	}

	body, err := io.ReadAll(response.Body)
	if err != nil {
		return err
	}

	return json.Unmarshal(body, target)
}

func NewProcessor(baseUrl string, apiToken string) *Processor {
	return &Processor{
		BaseUrl:    baseUrl,
		ApiToken:   apiToken,
		HttpClient: http.Client{},
	}
}
