// TOOD: This should not be necessary, but without it the
// Debian package build does not work. Figure out why.
//
//go:debug httpmuxgo121=0
package main

import (
	"flag"
	"log"
	"log/slog"
	"net"
	"net/http"
	"net/http/pprof"
	"os"

	"git.majava.org/software/tripla/tripla-gtfs-proxy/pkg/config"
	"git.majava.org/software/tripla/tripla-gtfs-proxy/pkg/proxy"
	"git.majava.org/software/tripla/tripla-gtfs-proxy/pkg/server"
)

func startDebugServer() {
	mux := http.NewServeMux()
	mux.HandleFunc("/debug/pprof/", pprof.Index)

	listener, err := net.Listen("tcp", "127.0.0.1:0")
	if err != nil {
		log.Fatal(err)
	}

	slog.Info("Started debug server",
		"address", listener.Addr())
	log.Fatal(http.Serve(listener, mux))
}

func main() {
	go startDebugServer()

	configPath := flag.String("config-path", "", "")
	triplaBaseUrl := flag.String("tripla-base-url", "http://app-httpd/api", "")
	triplaApiToken := flag.String("tripla-api-token", os.Getenv("TRIPLA_GTFS_PROXY_API_TOKEN"), "")
	bindOn := flag.String("bind-on", ":8000", "")
	flag.Parse()

	if *triplaApiToken == "" {
		log.Fatalln("An API token must be specified either as a flag or as an environment value")
	}

	cfg := &config.Config{}
	if *configPath != "" {
		var err error
		cfg, err = config.LoadConfig(*configPath)
		if err != nil {
			log.Fatal(err)
		}
	}

	p := proxy.NewProxy(*triplaBaseUrl, *triplaApiToken, cfg)
	ps := server.ProxyServer{Proxy: p}
	handler := ps.GetHandler()

	listener, err := net.Listen("tcp", *bindOn)
	if err != nil {
		log.Fatal(err)
	}

	slog.Info("Started server",
		"address", listener.Addr())
	log.Fatal(http.Serve(listener, handler))
}
