package proxy

import (
	"archive/zip"
	"encoding/csv"
	"io"
)

type CsvFile struct {
	Columns       []string
	ColumnIndexes map[string]int
	Values        [][]string
}

func readCsvRows(r *csv.Reader) (*CsvFile, error) {
	columns, err := r.Read()
	if err != nil {
		return nil, err
	}

	columnIndexes := map[string]int{}
	for i, column := range columns {
		columnIndexes[column] = i
	}

	rows := [][]string{}

	for {
		values, err := r.Read()
		if err != nil {
			if err == io.EOF {
				break
			}

			return nil, err
		}

		rows = append(rows, values)
	}

	return &CsvFile{
		Columns:       columns,
		ColumnIndexes: columnIndexes,
		Values:        rows,
	}, err
}

func (file CsvFile) ToJson() []map[string]string {
	data := make([]map[string]string, len(file.Values))
	for i, value := range file.Values {
		data[i] = map[string]string{}
		for j, column := range file.Columns {
			data[i][column] = value[j]
		}
	}
	return data
}

func parseZipFile(file *zip.File) (*CsvFile, error) {
	r, err := file.Open()
	if err != nil {
		return nil, err
	}
	defer r.Close()

	content := csv.NewReader(r)
	rows, err := readCsvRows(content)
	return rows, err
}
