package main

import (
	"flag"
	"fmt"
	"net/http"
	"os"

	"github.com/prometheus/client_golang/prometheus/promhttp"

	"git.majava.org/software/tripla/tripla-gtfs-rt/pkg/processor"
)

func main() {
	baseUrl := flag.String("base-url", "http://app-httpd/api", "")
	apiToken := flag.String("api-token", os.Getenv("TRIPLA_GTFSRT_API_TOKEN"), "")
	flag.Parse()

	p := processor.NewProcessor(*baseUrl, *apiToken)

	sources := []*processor.GtfsRtSource{}
	err := p.GetAndParseJson(fmt.Sprintf("/internal/live/sources/%v", processor.DataSourceType), &sources)
	if err != nil {
		panic(err)
	}

	p.StartSources(sources)
	p.StartJourneyUpdater()

	http.Handle("/metrics", promhttp.Handler())
	err = http.ListenAndServe(":8000", nil)
	if err != nil {
		panic(err)
	}
}
